/***************************************************************************
                          kmp.h  -  description
                             -------------------
    begin                : Don Apr 17 11:30:44 CEST 2003
    copyright            : (C) 2003 by J.Kofler
    email                : kaffeine@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMP_H
#define KMP_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kapp.h>
#include <kstdaction.h>
#include <klocale.h>
#include <kaction.h>
#include <kpopupmenu.h>
#include <kmenubar.h>
#include <kaboutapplication.h>
#include <khelpmenu.h>
#include <kfiledialog.h>
#include <kbookmarkmanager.h>
#include <kbookmarkmenu.h>

#include <qwidget.h>
#include <qlayout.h>
#include <qsignalmapper.h>

#include "splashwidget.h"
#include "controlpanel.h"
#include "inforow.h"
#include "playlist.h"
#include "configwidget.h"
#include "xineconfig.h"
#include "videosettings.h"
#include "videowindow.h"




/** KMP is the base class of the project */
class KMP : public QWidget, virtual public KBookmarkOwner
{
  Q_OBJECT 
  public:
    /** construtor */
    KMP(QWidget* parent=0, const char *name=0);
    /** destructor */
    ~KMP();

    void Finalize();
    
    void CmdArgs(const KURL::List& files, bool playAtStartup, bool startFullscreen);
    void LoadPlaylist();

    VideoWindow* videoWin;

   //overloaded bookmarkowner methods
    virtual void openBookmarkURL(const QString&);
    virtual QString currentTitle() const;
    virtual QString currentURL() const;
    
  private slots:
    void slotQuit();
    void slotOpenFile();
    void slotOpenUrl();
    void slotPlay();
    void slotEndOfPlayback();
    void slotPlayNext();
    void slotPlayPrev();
    void slotPlayRecent(const KURL&);
    void slotPlayLOGO();
    void slotStop();
    void slotToggleFullscreen();
    void slotPlayAutoplayPlugin(const QString&);
    void slotShowPlayList();
    void slotShowSetup();
    void slotHasChapters(bool);
    void slotEndlessMode();
    void slotRandomPlay();
    void slotGenConfig(bool loadPl);
    void slotConfigXine();
    void slotVideoSettings();
    void slotScreenshot();
    void slotToggleTv();
    
  protected:

  virtual void closeEvent(QCloseEvent*);
  virtual void moveEvent(QMoveEvent*);
  virtual void dropEvent(QDropEvent*);
  virtual void dragEnterEvent(QDragEnterEvent*);
    
  private:

  PlayList* playList;
  ControlPanel* cPanel;
  TextRow* tRow;
  SplashWidget* osDisplay;
  ConfigWidget* configWin;
  VideoSettings* videoSettings;

  QString currentAutoPlayMrl;

  bool playSingleUrl;
  QString cUrl;
  QString cTitle;
  
  void InitActions();
  void InitMenu();
  void InitConnections();
  void ReadConfig();
  void SaveConfig();
  
  bool hasChapters;
  bool loadPlaylistAtStartup;

  QTimer playDelayedTimer;
  QTimer playLOGODelayedTimer;

  KConfig* config;

  KMenuBar* menuBar;
  KPopupMenu* fileMenu;
  KPopupMenu* playMenu;
  KPopupMenu* viewMenu;
  KPopupMenu* aspectMenu;
  KPopupMenu* configMenu;
  KPopupMenu* helpMenu;

  KPopupMenu* bookmarkMenu;
  KBookmarkMenu* bmenu;
  KBookmarkManager* bookmarkManager;

  KActionCollection* actionCollection;
  KAction* fileOpen;
  KAction* fileOpenUrl;
  KAction* fileSaveScreenshot;
  KAction* fileEject;
  KAction* fileQuit;
  KRecentFilesAction* playRecent;
  KToggleAction* playEndlessPlay;
  KToggleAction* playRandomPlay;
  KToggleAction* viewFullscreen;

  KAction* aspectRatioAuto;
  KAction* aspectRatio4_3;
  KAction* aspectRatio16_9;
  KAction* aspectRatioSquare;
  
  KToggleAction* viewDeinterlace;
  KAction* viewZoomIn;
  KAction* viewZoomOut;
  KAction* viewZoomOff;
  KToggleAction* viewToggleTv;
  KAction* configVideoControl;
  KAction* configXine;
  KAction* configKMP;

  KAction* autoPlayPlugin;

      
};

#endif
